@@ -396,9 +396,9 @@ L<Together We Remember|https://togetherweremember.com>
 
 	use WebService::TogetherWeRemember;
 
-	my $api = WebService::TogetherWeRemember->new();
+	my $twr = WebService::TogetherWeRemember->new();
 
-	$api->login($email, $password);
+	my $api = $twr->login($email, $password);
 
 	my $timeline = $api->timeline_create({
 		name => "My First Timeline",
